@@ -1,5 +1,5 @@
 from .circuit_braker import CircuitBreakerOpen, circuit_breaker  # noqa
-from .defaults import CacheDetect  # noqa
+from .defaults import CacheDetect, context_cache_detect  # noqa
 from .early import early  # noqa
 from .fail import fail  # noqa
 from .locked import locked  # noqa
